@@ -146,18 +146,20 @@ def get(dataset, **kwargs):
 
 def push(data, code, name, authtoken='', desc='', override=False, verbose=False, text=None):
     ''' Upload a pandas Dataframe to Quandl and returns link to the dataset.
+
     :param data: (required), pandas ts or numpy array
     :param str code: (required), Dataset code
                  must consist of only capital letters, numbers, and underscores
     :param str name: (required), Dataset name
     :param str authtoken: (required), to upload data
     :param str desc: (optional), Description of dataset
-    :param bool overide: (optional), whether to overide dataset of same code
     :param bool verbose: specify whether to print output text to stdout, default is False.
     :param str text: Deprecated. Use `verbose` instead.
+
     :returns: :str: link to uploaded dataset'''
 
-    override = str(override).lower()
+   
+
     if text is not None:
         print('Deprecated: "text" is deprecated and will be removed in next release, use "verbose" instead.')
         verbose = text
@@ -170,7 +172,6 @@ def push(data, code, name, authtoken='', desc='', override=False, verbose=False,
     #test that code is acceptable format
     _pushcodetest(code)
     datestr = ''
-
     # Verify and format the data for upload.
     if not isinstance(data, pd.core.frame.DataFrame):
         error = "only pandas DataFrames are accepted for upload at this time"
@@ -198,24 +199,47 @@ def push(data, code, name, authtoken='', desc='', override=False, verbose=False,
                 datestr += ',' + str(n)
         datestr += '\n'
 
+
+    url = QUANDL_API_URL + 'datasets'
+    # Try to POST, will fail if dataset already exists   
     params = {'name': name,
               'code': code,
               'description': desc,
-              'update_or_create': override,
-              'data': datestr}
+              'data': datestr,
+              'auth_token': token}
+    resp = requests.post(url,params = params)
+    rtn = resp
+    if resp.status_code == 200 or resp.status_code == 422:
+        user_source_code = resp.json()['source_code']
+        #Catch failed POST and PUT instead to update
+        if resp.json()['errors']['code'] == [u'has already been taken']:
+            
 
-    url = QUANDL_API_URL + 'datasets.json?auth_token=' + token
-    jsonreturn = _htmlpush(url, params)
-    if (jsonreturn['errors']
-        and jsonreturn['errors']['code'][0] == 'has already been taken'):
-        error = ("You are trying to overwrite a dataset which already "
-                 "exists on Quandl. If this is what you wish to do please "
-                 "recall the function with overide = True")
-        raise ValueError(error)
+            
 
-    rtn = ('http://www.quandl.com/' + jsonreturn['source_code'] + '/' +
-           jsonreturn['code'])
-    #Return URL of uploaded dataset
+            # make put request
+            url += "/{user_source_code}/{code}".format(**locals())
+            put_data = {'name':name,
+                        'descripton':desc,
+                        'data':datestr,
+                        'auth_token':token
+                        }
+            put_resp = requests.put(url,params =put_data)
+            rtn = put_resp
+    elif resp.status_code == 401:
+        error = ("Authtoken does not corrrospond to a Quandl Account"
+             " please make sure you are using the correct token")
+        raise TokenError(error)
+    elif resp.status_code in range(500,600):
+        error = ("Server Error. We apologize, something went wrong on our end. Please try call again in a minute, and email us at connect@quandl.com if this error persists.")
+        raise QuandlError(error)
+    else:
+        error = ("Unknown response ({r}). Please copy and paste the error output, and the file you are running, and email us at connect@quandl.com. We will help you fix your error ASAP.".format(str(resp.status_code))
+        raise UnknownError(error)
+
+
+
+    #Return JSON response of uploaded dataset
     return rtn
 
 
